<?php
namespace Pinpoint\BlankProduct\Plugin\Model\Stock;

use \Magento\Framework\Registry;
use \Magento\Backend\Model\Auth\Session as AuthSession;

/**
 * Class ItemPlugin
 * @package Pinpoint\BlankProduct\Plugin\Model\Stock
 */
class ItemPlugin
{
    /**
     * @var Registry
     */
    protected $_coreRegistry;

    /**
     * @var AuthSession
     */
    protected $_authSession;

    /**
     * @var \Pinpoint\BlankProduct\Helper\Quantity
     */
    protected $quantityHelper;

    /**
     * ItemPlugin constructor.
     * @param Registry $coreRegistry
     * @param AuthSession $authSession
     * @param \Pinpoint\BlankProduct\Helper\Quantity $quantityHelper
     */
    public function __construct(
        Registry $coreRegistry,
        AuthSession $authSession,
        \Pinpoint\BlankProduct\Helper\Quantity $quantityHelper
    ) {
        $this->_coreRegistry = $coreRegistry;
        $this->_authSession = $authSession;
        $this->quantityHelper = $quantityHelper;
    }

    /**
     * @param \Magento\CatalogInventory\Model\Stock\Item $subject
     * @param $result
     * @return bool|int
     */
    public function afterGetIsInStock(\Magento\CatalogInventory\Model\Stock\Item $subject, $result)
    {
        if(!$this->_authSession->isLoggedIn()) {
            if ($this->_coreRegistry->registry('stockitem_getisinstock') !== 'value') {
                $this->_coreRegistry->register('stockitem_getisinstock', 'value');
                if ($result === false) {
                    // look up this product to see if there are any blank products
                    $blankProduct = $this->quantityHelper->getBlankProductStockItem($subject->getProductId());
                    if ($blankProduct) {
                        $result = $blankProduct;
                        $this->_coreRegistry->unregister('stockitem_getisinstock');
                        return $result;
                    }
                }
                $this->_coreRegistry->unregister('stockitem_getisinstock');
            }
        }
        return $result;
    }
}